<?php

namespace App\Http\Controllers;

use App\Http\Requests\HabitsRequest;
use App\Models\Category;
use App\Models\Habit;
use App\Models\Tag;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class HabitController extends Controller
{
    public function index()
    {
        return view('habits.index', [
            'habits' => Auth::user()->habits->sortBy('category'),
        ]);
    }

    public function create()
    {
        $habit = new Habit;

        return view('habits.create', [
            'habit' => $habit,
            'update' => 0,
            'today' => now()->format('Y-m-d')
        ]);
    }

    public function store(HabitsRequest $request)
    {
        $validata = $request->safe();

        $habit = new Habit($validata->all());
        $habit->user_id = $request->user()->id;
        $habit->save();

        // Category - add if a name is entered
        if (!is_null($validata->only('category')['category'])) {
            $category = Category::firstOrCreate(['name' => $validata->only('category')['category']]);
            $habit->category()->associate($category);
            $habit->save();
        }

        // Tags
        if (!is_null($validata->only('tags')['tags'])) {
            $tagsArray = explode(', ', $request->only('tags')['tags']);

            foreach ($tagsArray as $tag) {
                $tag = Tag::firstOrCreate(['name' => $tag], ['habit_id' => $habit->id]);
                $habit->tags()->attach($tag);
                //Todo: make sure tag isn't already linked
            }
            $habit->save();
        }

        return redirect()->route('habits.index')->with('status', 'created');
    }

    public function show($id)
    {
        $habit = Habit::find($id);

        return view('habits.show', [
            'habit' => $habit,
            'update' => 0,
            'entries' => $habit->entries->sortByDesc('date')
        ]);

    }

    public function edit($id)
    {
        $habit = Habit::find($id);

        return view('habits.edit', [
            'habit' => $habit,
            'update' => 1
        ]);
    }

    public function update(Request $request, $id)
    {
        $habit = Habit::find($id);

        $habit->update($request->safe());


    }

    public function destroy($id)
    {
    }
}
