<div>
    <form action="{{$update ? route('habits.update', $habit) : route('habits.store')}}" method="post">

        @if ($update)
            @method('PUT')
        @endif

        @csrf
        <div class="grid grid-cols-1 lg:grid-cols-2 gap-5">
            <x-pagecard>

                <!-- Name -->
                <div>
                    <x-input-label for="name" :value="__('Name')"/>
                    <x-text-input id="name" class="block mt-1 w-full" type="text" name="name"
                                  placeholder="Swimming" required autofocus autocomplete="name"
                                  :value="old('name', $habit->name)"
                    />

                    <x-input-error :messages="$errors->get('name')" class="mt-2"/>
                </div>

                <!-- Question -->
                <div class="mt-6">
                    <x-input-label for="question" value="Question to ask"/>
                    <x-text-input id="question" class="block mt-1 w-full" type="text" name="question"
                                  placeholder="For how long did I swim?" :value="old('question', $habit->question)"
                                  autocomplete="question"/>

                    <x-input-error :messages="$errors->get('question')" class="mt-2"/>
                </div>

                <!-- Category input -->
                <div class="mt-6">
                    <x-input-label for="category" value="Category"/>
                    <x-text-input id="category" class="block mt-1 w-full" type="text" name="category"
                                  placeholder="Exercise"
                                  :value="old('category', isset($habit->category->name) ? $habit->category->name : '' )"
                                  autocomplete="category"/>

                    <x-input-error :messages="$errors->get('category')" class="mt-2"/>
                </div>

                <!-- tag input -->
                <div class="mt-6">
                    <x-input-label for="tag" value="Tags"/>
                    <x-text-input id="tag" class="block mt-1 w-full" type="text" name="tags"
                                  placeholder="Exercise, swimming, health"
                                  :value="old('tag', $habit->tagsToString())" autocomplete="tag"/>
                    <x-input-error :messages="$errors->get('tag')" class="mt-2"/>
                </div>
            </x-pagecard>

            <x-pagecard>

                <!-- Type -->
                <div class="">
                    <x-input-label for="habit_type" value="Habit Type"></x-input-label>
                    <div class="flex items-center mb-1 mt-1">

                        <!-- Radio button: todo-->
                        <input id="habit-type-1" type="radio" value="todo" name="type"
                               onclick="toggleHabitValueSuffix(true)" checked
                               class="w-4 h-4 text-blue-600 bg-gray-50 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600">
                        <label for="habit-type-1" class="ml-2">Todo</label>
                    </div>

                    <!-- Radio button: value-->
                    <div class="flex items-center mb-1">
                        <input id="habit-type-2" type="radio" value="value" name="type"
                               onclick="toggleHabitValueSuffix(false)"
                               class="w-4 h-4 text-blue-600 bg-gray-50 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600">
                        <label for="habit-type-2" class="ml-2 ">Amount and suffix</label>
                    </div>

                    <!-- Value / Suffix -->
                    <x-input-label for="value" value="Suffix" class="mt-4"
                                   id="habit-suffix-label"/>

                    <x-text-input id="habit-suffix-name" class="inline-block mt-1 disabled:opacity-50 w-1/2"
                                  type="text" name="suffix" disabled required
                                  placeholder="minutes"
                                  :value="old('suffix', isset($habit->suffix) ? $habit->suffix : '')"
                                  autocomplete="suffix"/>
                    <x-input-error :messages="$errors->get('suffix')" class="mt-2"/>
                </div>

                <hr class="my-5">

                <!-- Schedule -->
                <div class="">
                    <x-input-label for="schedule-value" value="Schedule Recurrence"></x-input-label>
                    <div class="text-sm my-1 text-gray-700 mr-20">
                        The recurrence value determines how often you will be inquired about this habit.
                        Note: this is
                        different from setting a goal.
                    </div>
                    <div class="inline-block mt-4 pr-1">
                        Every
                    </div>
                    <x-text-input id="schedule-value" class="inline-block mt-1 w-20" type="number"
                                  placeholder="" min="0" value="1" name="schedule_value"
                                  :value="old('schedule_value', isset($habit->schedule_value) ? $habit->schedule_value : '0')"
                    />
                    <x-input-error :messages="$errors->get('schedule_value')" class="mt-2"/>

                    <select name="schedule_unit" id="schedule-unit"
                            class="inline-block w-fit border-gray-300 dark:border-gray-700 dark:bg-gray-900 dark:text-gray-300 focus:border-indigo-500 dark:focus:border-indigo-600 focus:ring-indigo-500 dark:focus:ring-indigo-600 rounded-md shadow-sm">

                        @foreach(['day', 'week', 'month'] as $time_unit)
                            <option value="{{$time_unit}}"
                                    @if($habit->schedule_unit === $time_unit) selected @endif >{{$time_unit}}s
                            </option>
                        @endforeach
                    </select>

                    <div class="inline-block mt-1 px-1">
                        starting
                    </div>

                    <x-text-input type="date" class="inline-block mt-1" name="schedule_start" id="schedule_start"
                                  :value="old('schedule_start', isset($habit->schedule_start) ? $habit->schedule_start : $today)"
                                  required/>
                </div>
            </x-pagecard>

            <!-- Goal -->
            <x-pagecard>
                <div class="">
                    <x-input-label value="Goal Type"></x-input-label>
                    <div class="text-sm my-2 text-gray-700">
                        Setting a goal will show you how well you're doing, based on the entries made.
                        If you only want to record the frequency of an activity, you don't need to set a
                        goal.
                    </div>
                    <div class="flex items-center mb-1">
                        <input id="goal-type-1" type="radio" value="none" name="goal_type"
                               onclick="toggleGoalSchedule(true)" @if($habit->goal_type === 'none') checked @elseif(!isset($habit->goal_type)) checked @endif
                               class="w-4 h-4 text-blue-600 bg-gray-50 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600">
                        <label for="goal-type-1" class="ml-2">No goal</label>
                    </div>
                    <div class="flex items-center mb-1">
                        <input id="goal-type-2" type="radio" value="schedule" name="goal_type"
                               onclick="toggleGoalSchedule(true)" @if($habit->goal_type === 'schedule') checked @endif
                               class="w-4 h-4 text-blue-600 bg-gray-50 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600">
                        <label for="goal-type-2" class="ml-2 ">Same as schedule</label>
                    </div>
                    <div class="flex items-center mb-1">
                        <input id="goal-type-3" type="radio" value="custom" name="goal_type"
                               onclick="toggleGoalSchedule(false)" @if($habit->goal_type === 'custom') checked @endif
                               class="w-4 h-4 text-blue-600 bg-gray-50 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600">
                        <label for="goal-type-3" class="ml-2 ">Custom schedule</label>
                    </div>
                </div>
                <hr class="mt-4">

                <!-- goal schedule -->
                <div class="mt-4">
                    <x-input-label for="goal-schedule-unit" value="Goal Recurrence"/>
                    <div class="inline-block mt-1 pr-1">
                        Every
                    </div>

                    <x-text-input id="goal-schedule-amount" class="inline-block mt-1 w-20" type="number"
                                  :value="old('goal_value', isset($habit->goal_value) ? $habit->goal_value : '0')"
                                  placeholder="" min="0" disabled
                                  required name="goal_value"/>

                    <x-input-error :messages="$errors->get('goal_value')" class="mt-2"/>


                    <select name="goal_unit" id="goal-schedule-unit"
                            disabled required
                            class="inline-block w-fit border-gray-300 dark:border-gray-700 dark:bg-gray-900 dark:text-gray-300 focus:border-indigo-500 dark:focus:border-indigo-600 focus:ring-indigo-500 dark:focus:ring-indigo-600 rounded-md shadow-sm disabled:opacity-50">
                        @foreach(['day', 'week', 'month'] as $time_unit)
                            <option value="{{$time_unit}}"
                                    @if($habit->goal_unit === $time_unit) selected @endif >{{$time_unit}}s
                            </option>
                        @endforeach
                    </select>

                    <div class="inline-block mt-1 px-1">
                        starting
                    </div>

                    <x-text-input type="date" class="inline-block mt-1" name="goal_start" id="goal-start"
                                  :value="old('goal_start', isset($habit->goal_start) ? $habit->goal_start : $today)" disabled required/>
                </div>

            </x-pagecard>
            <x-pagecard>
                <div class="w-full h-full">
                    <div class="grid grid-row gap-10 h-full content-center">
                        <div class="text-7xl text-center">
                            🚀🌌
                        </div>
                        <div>
                            <hr>
                        </div>

                        <div class="text-center">
                            <x-primary-button class="px-20 py-4 shadow-md">
                                @if(isset($habit))
                                    Save Changes
                                @else
                                    Create Habit
                                @endif
                            </x-primary-button>
                        </div>
                    </div>
                </div>
            </x-pagecard>

            <!-- Submit -->
            <div class="w-full">
            </div>
        </div>

    </form>

    <script>
        const habit_suffix = document.getElementById('habit-suffix-name');

        const goal_amount = document.getElementById('goal-schedule-amount');
        const goal_unit = document.getElementById('goal-schedule-unit');
        const goal_start = document.getElementById('goal-start');

        function toggleHabitValueSuffix(value) {
            habit_suffix.disabled = value;
        }

        function toggleGoalSchedule(value) {
            goal_amount.disabled = value;
            goal_unit.disabled = value;
            goal_start.disabled = value;
        }
    </script>
</div>
